/* lcd_betwek
 *  
 * Magyar ékezetes kisbetűk definiálása és használata.
 * Az ö bett a karaktergenerátorból vesszük 0xEF kóddal.
 * A program 4x16 karakteres kijelzőre készült.
 * Kétsoros kijelzőhöz így módosítsuk a programot:
 * 1. Írjuk át az lcb.begin(16,4) sort (pl. 16,2-re)
 * 2. Töröljük ki, vagy tegyük megjegyzéssé ezt a két sort: 
 *   lcd.print("t\006k\357rf\005r\003g\001p");
 *   lcd.setCursor(0,2);
 *   
 *   A program használata:
 *   1. Nyissunk egy temniálablakot!
 *   2. Indítás után az "árvíztűrő tükörfúrógép" felirat
 *   jelenik meg. Ahogy a programban is láthatjuk, az
 *   lcd.pront parancsban visszadőlő "per" jel után
 *   háromjegyű oktális kóddal hivatkozhatunk az ékezetes
 *   betűkre. A \000 szám nem nyerő, használjuk az alternatív
 *   \010 (decimális 8) kódot!
 *   3. Ezután a terminálból karaktereket küldhetünk
 *   az Arduinónak. A vett ékezetes karakterek átkódolás 
 *   (behelyettesítés) után kerülnek ki az LCD kijelzőre.
 *   
 *   A program eredeti változata a 60 nap alatt Arduino tanfolyam
 *   anyagából való (c) TavIR http://avr.tavir.hu 
 *   A programot némileg módosítottuk (I. Cserny, 2019)
 */

#include "LiquidCrystal.h"           //LCD kijelzőt használunk
LiquidCrystal lcd(12, 11, 5, 4, 3, 2); //bekotjuk az LCD-t

//kis ekezetes betuk
byte a1[8] = {B10, B100, B1110, B1, B1111, B10001, B1111};
byte e1[8] = {B10, B100, B1110, B10001, B11111, B10000, B1110};
byte i1[8] = {B10, B100, B0, B1110, B100, B100, B1110};
byte o1[8] = {B100, B100, B0, B1110, B10001, B10001, B1110};
byte o2[8] = {B1010, B0, B1110, B10001, B10001, B10001, B1110};
byte o3[8] = {B1010, B1010, B0000, B1110, B10001, B10001, B1110};
byte u1[8] = {B0010, B0100, B10001, B10001, B10001, B10011, B1101};
byte u2[8] = {B1010, B0, B0, B10001, B10001, B10011, B1101};
byte u3[8] = {B1010, B1010, B0, B10001, B10001, B10011, B1101};


byte b; //atmeneti valtozo

void setup() {
  lcd.createChar(0, a1);
  lcd.createChar(1, e1);
  lcd.createChar(2, i1);
  lcd.createChar(3, o1);
  lcd.createChar(4, o3);
  lcd.createChar(5, u1);
  lcd.createChar(6, u2);
  lcd.createChar(7, u3);
  //karakterdefinialas
  //o:-nek nincs hely!
  lcd.begin(16, 4);   //4x16 karakteres LCD
  lcd.print("\010rv\002zt\007r\004");
  lcd.setCursor(0,1);
  lcd.print("t\006k\357rf\005r\003g\001p");
  lcd.setCursor(0,2);
  Serial.begin(9600); //Sorosport 9600 bps nyitasa
}

void loop() {
  if (Serial.available()) {
    b = Serial.read();   //ha van karakter: beolvassuk
    Serial.print(b, DEC); //kiirjuk a Windows karakterkodjat
    Serial.print(": "); 
    //karakterkod alapjan csere:
    switch (b) {
      case 225: b = 0; break;
      case 233: b = 1; break;
      case 237: b = 2; break;
      case 243: b = 3; break;
      case 245: b = 4; break;
      case 246: b = 0xEF; break;
      case 250: b = 5; break;
      case 252: b = 6; break;
      case 251: b = 7; break;
    }
    Serial.println(b, DEC); //kiirjuk a LCD karakterkodjat
    lcd.write(b);      //akkor irjuk ki az LCD-re    
    delay(150);
  }
}
